Struct DebugContext

pub struct DebugContext<'own> {
    pub theme: &'own Theme,
    pub format: DebugFormat,
    pub inline: bool,
    pub separator: bool,
    pub indentation: String,
}
Debug context.

Used with Debuggable to keep track of the mode and graphical structure.

Fields

theme: &'own Theme

Theme.

format: DebugFormat

Format.

Defaults to DebugFormat::Reduced.

inline: bool

Whether we are continuing a single-line representation.

Defaults to false.

separator: bool

Whether we should insert a separator before the representation.

Defaults to false.

indentation: String

Indentation for multi-line representations.

Implementations

Source

impl<'own> DebugContext<'own>

pub fn new(theme: &'own Theme) -> Self

Constructor.

pub fn child(&self) -> Self

Create child context.

Will set inline to false and clone the other fields.

pub fn with_theme(self, theme: &'own Theme) -> Self

Change the theme.

pub fn with_format(self, format: DebugFormat) -> Self

Change the format.

pub fn with_inline(self, inline: bool) -> Self

Change the inline flag.

Note that the other “with_” functions set inline to false, so make sure to call this function at the end of “with_” chains.

pub fn with_separator(self, separator: bool) -> Self

Change the separator.

pub fn increase_indentation(self) -> Self

Increase the indentation with spaces.

pub fn increase_indentation_branch(self, last: bool) -> Self

Increase the indentation with a branch continuation.

pub fn increase_indentation_thick_branch(self, last: bool) -> Self

Increase the indentation with a thick branch continuation.

pub fn increase_indentation_double_branch(self, last: bool) -> Self

Increase the indentation with a double branch continuation.

pub fn separate<WriteT>(&self, writer: &mut WriteT) -> Result<()>
where WriteT: Write,

If the separate flag is true, write the separator.

pub fn indent<WriteT>(&self, writer: &mut WriteT) -> Result<()>
where WriteT: Write,

Write a newline plus the indentation.

pub fn indent_into<WriteT>( &self, writer: &mut WriteT, delimiter: &str, ) -> Result<()>
where WriteT: Write,

Write a newline plus the indentation. Then write a custom delimiter.

pub fn indent_into_branch<WriteT>( &self, writer: &mut WriteT, last: bool, ) -> Result<()>
where WriteT: Write,

Write a newline plus the indentation plus a branch-into delimiter.

pub fn indent_into_thick_branch<WriteT>( &self, writer: &mut WriteT, last: bool, ) -> Result<()>
where WriteT: Write,

Write a newline plus the indentation plus a thick branch-into delimiter.

pub fn indent_into_double_branch<WriteT>( &self, writer: &mut WriteT, last: bool, ) -> Result<()>
where WriteT: Write,

Write a newline plus the indentation plus a double branch-into delimiter.

pub fn separate_or_indent<WriteT>( &self, writer: &mut WriteT, first: bool, ) -> Result<()>
where WriteT: Write,

If the inline flag is false and first is true, write the separator. Otherwise write a newline plus the indentation.

pub fn separate_or_indent_into<WriteT>( &self, writer: &mut WriteT, delimiter: &str, first: bool, ) -> Result<()>
where WriteT: Write,

If the inline flag is false and first is true write the separator. Otherwise write a newline plus the indentation. Then write a custom delimiter.