pub struct DebugPrefix { /* private fields */ }Expand description
Debug prefix.
Utility for implementing multi-line Debuggable output in a nested horizontal tree-like structure.
Implementations
Sourceimpl DebugPrefix
impl DebugPrefix
Sourcepub fn with_branch(&self, last: bool) -> Self
pub fn with_branch(&self, last: bool) -> Self
Clone and add a branch-style suffix.
Sourcepub fn with_thick_branch(&self, last: bool) -> Self
pub fn with_thick_branch(&self, last: bool) -> Self
Clone and add a thick branch-style suffix.
Sourcepub fn with_double_branch(&self, last: bool) -> Self
pub fn with_double_branch(&self, last: bool) -> Self
Clone and add a double branch-style suffix.
Sourcepub fn write<WriteT>(&self, writer: &mut WriteT) -> Result<()>where
WriteT: Write,
pub fn write<WriteT>(&self, writer: &mut WriteT) -> Result<()>where
WriteT: Write,
Write a newline plus this prefix.
Sourcepub fn conditional_write<WriteT>(
&self,
writer: &mut WriteT,
first: bool,
) -> Result<()>where
WriteT: Write,
pub fn conditional_write<WriteT>(
&self,
writer: &mut WriteT,
first: bool,
) -> Result<()>where
WriteT: Write,
If first is false, write a newline plus this prefix.
Sourcepub fn write_with<WriteT>(
&self,
writer: &mut WriteT,
suffix: &str,
) -> Result<()>where
WriteT: Write,
pub fn write_with<WriteT>(
&self,
writer: &mut WriteT,
suffix: &str,
) -> Result<()>where
WriteT: Write,
Write a newline plus this prefix. Then write a custom suffix.
Sourcepub fn conditional_write_with<WriteT>(
&self,
writer: &mut WriteT,
suffix: &str,
first: bool,
) -> Result<()>where
WriteT: Write,
pub fn conditional_write_with<WriteT>(
&self,
writer: &mut WriteT,
suffix: &str,
first: bool,
) -> Result<()>where
WriteT: Write,
If first is false, write a newline plus this prefix. Then write a custom suffix. The custom suffix is always written.
Sourcepub fn write_with_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
pub fn write_with_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
Write a newline plus this prefix plus a branch-style suffix.
Sourcepub fn write_with_thick_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
pub fn write_with_thick_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
Write a newline plus this prefix plus a thick branch-style suffix.
Sourcepub fn write_with_double_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
pub fn write_with_double_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
Write a newline plus this prefix plus a double branch-style suffix.