pub fn run<E: HasExit + Display>(run: Runner<E>) -> ExitCodeExpand description
Runs a Runner, handling a returned Exit.
If the exit has a goodbye message, it will be printed to stderr. If the exit code is an error (non-zero) it will be in red.
Non-exit errors will be displayed in red.
Designed to be the only content for your main function. The
good stuff should go into your Runner.