Function run

pub fn run<ErrorT>(run: Runner<ErrorT>) -> ExitCode
where ErrorT: HasExit + Display,
Runs a Runner, handling a returned Exit.

If the exit has a goodbye message, it will be printed to stderr. If the exit code is an error (non-zero) it will be in red.

Non-exit errors will be displayed in red.

Designed to be the only content for your main function. The good stuff should go into your Runner.