pub struct DebugContext<'own> {
pub theme: &'own Theme,
pub format: DebugFormat,
pub inline: bool,
pub separator: bool,
pub indentation: String,
}Expand description
Debug context.
Used with Debuggable to keep track of the mode and graphical structure.
Fields
theme: &'own ThemeTheme.
format: DebugFormatFormat.
Defaults to DebugFormat::Reduced.
inline: boolWhether we are continuing a single-line representation.
Defaults to false.
separator: boolWhether we should insert a separator before the representation.
Defaults to false.
indentation: StringIndentation for multi-line representations.
Implementations
Sourceimpl<'own> DebugContext<'own>
impl<'own> DebugContext<'own>
Sourcepub fn child(&self) -> Self
pub fn child(&self) -> Self
Create child context.
Will set inline to false and clone the other fields.
Sourcepub fn with_theme(self, theme: &'own Theme) -> Self
pub fn with_theme(self, theme: &'own Theme) -> Self
Change the theme.
Sourcepub fn with_format(self, format: DebugFormat) -> Self
pub fn with_format(self, format: DebugFormat) -> Self
Change the format.
Sourcepub fn with_inline(self, inline: bool) -> Self
pub fn with_inline(self, inline: bool) -> Self
Change the inline flag.
Note that the other “with_” functions set inline to false, so make sure to call this function at the end of “with_” chains.
Sourcepub fn with_separator(self, separator: bool) -> Self
pub fn with_separator(self, separator: bool) -> Self
Change the separator.
Sourcepub fn increase_indentation(self) -> Self
pub fn increase_indentation(self) -> Self
Increase the indentation with spaces.
Sourcepub fn increase_indentation_branch(self, last: bool) -> Self
pub fn increase_indentation_branch(self, last: bool) -> Self
Increase the indentation with a branch continuation.
Sourcepub fn increase_indentation_thick_branch(self, last: bool) -> Self
pub fn increase_indentation_thick_branch(self, last: bool) -> Self
Increase the indentation with a thick branch continuation.
Sourcepub fn increase_indentation_double_branch(self, last: bool) -> Self
pub fn increase_indentation_double_branch(self, last: bool) -> Self
Increase the indentation with a double branch continuation.
Sourcepub fn separate<WriteT>(&self, writer: &mut WriteT) -> Result<()>where
WriteT: Write,
pub fn separate<WriteT>(&self, writer: &mut WriteT) -> Result<()>where
WriteT: Write,
If the separate flag is true, write the separator.
Sourcepub fn indent<WriteT>(&self, writer: &mut WriteT) -> Result<()>where
WriteT: Write,
pub fn indent<WriteT>(&self, writer: &mut WriteT) -> Result<()>where
WriteT: Write,
Write a newline plus the indentation.
Sourcepub fn indent_into<WriteT>(
&self,
writer: &mut WriteT,
delimiter: &str,
) -> Result<()>where
WriteT: Write,
pub fn indent_into<WriteT>(
&self,
writer: &mut WriteT,
delimiter: &str,
) -> Result<()>where
WriteT: Write,
Write a newline plus the indentation. Then write a custom delimiter.
Sourcepub fn indent_into_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
pub fn indent_into_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
Write a newline plus the indentation plus a branch-into delimiter.
Sourcepub fn indent_into_thick_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
pub fn indent_into_thick_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
Write a newline plus the indentation plus a thick branch-into delimiter.
Sourcepub fn indent_into_double_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
pub fn indent_into_double_branch<WriteT>(
&self,
writer: &mut WriteT,
last: bool,
) -> Result<()>where
WriteT: Write,
Write a newline plus the indentation plus a double branch-into delimiter.
Sourcepub fn separate_or_indent<WriteT>(
&self,
writer: &mut WriteT,
first: bool,
) -> Result<()>where
WriteT: Write,
pub fn separate_or_indent<WriteT>(
&self,
writer: &mut WriteT,
first: bool,
) -> Result<()>where
WriteT: Write,
If the inline flag is false and first is true, write the separator. Otherwise write a newline plus the indentation.
Sourcepub fn separate_or_indent_into<WriteT>(
&self,
writer: &mut WriteT,
delimiter: &str,
first: bool,
) -> Result<()>where
WriteT: Write,
pub fn separate_or_indent_into<WriteT>(
&self,
writer: &mut WriteT,
delimiter: &str,
first: bool,
) -> Result<()>where
WriteT: Write,
If the inline flag is false and first is true write the separator. Otherwise write a newline plus the indentation. Then write a custom delimiter.